from setuptools import setup

setup(
   name='haithoum21',
   version='1.0.0',
   author='Haitham',
   author_email='haithambadereddine.dz@gmail.com',
   packages=['rocket'],
   url='http://pypi.python.org/pypi/rocket/',
   license='LICENSE.txt',
   description='An awesome package that does something',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   install_requires=['rocket']
)